@@ -66,12 +66,14 @@ def create_branch_names(prefix: str) -> Dict[str, str]:
         "ProbNNpi": f"{prefix}_MC15TuneV1_ProbNNpi",
         "ProbNNk": f"{prefix}_MC15TuneV1_ProbNNk",
         "P": f"{prefix}_P",
+        "Brunel_P": f"{prefix}_Brunel_P",
         "ETA": f"{prefix}_ETA",
+        "Brunel_ETA": f"{prefix}_Brunel_ETA",
         "nTracks": "nTracks",
         "nTracks_Brunel": "nTracks_Brunel",
         "nSPDhits": "nSPDhits",
         "nSPDhits_Brunel": "nSPDhits_Brunel",
-        "sw": f"{prefix}_sWeight",
+        "sWeight": f"{prefix}_sWeight",
         "TRCHI2NDOF": f"{prefix}_TRCHI2NDOF",
     }
     return branch_names
@@ -96,7 +98,7 @@ def get_relevant_branch_names(
 
     # Remove sWeight if not a calib sample
     if prefix != "probe":
-        del branch_names["sw"]
+        del branch_names["sWeight"]
 
     # Create a list of vars in the PID cuts
     pid_cuts_vars = []
@@ -108,7 +110,7 @@ def get_relevant_branch_names(
 
     # Remove all vars that are not used for binning or PID cuts
     for branch in tuple(branch_names):
-        if branch not in [*pid_cuts_vars, *bin_vars, "sw"]:
+        if branch not in [*pid_cuts_vars, *bin_vars, "sWeight"]:
             del branch_names[branch]
 
     # Add vars in the arbitrary cuts
@@ -316,12 +318,12 @@ def get_calib_hists(
     magnet: str,
     ref_pars: Dict[str, List[str]],
     bin_vars: Dict[str, str],
-) -> Dict[str, bh.Histogram]:
+) -> Dict[str, Dict[str, bh.Histogram]]:
     """Get calibration efficiency histograms from all necessary files.
 
     Args:
         hist_dir: Directory where to look for the required files.
-        year: Data-taking year.
+        sample: Data sample name (Turbo18, etc.).
         magnet: Magnet polarity (up, down).
         ref_pars: Reference particle prefixes with a particle type and PID cut.
         bin_vars: Binning variables ({standard name: reference sample branch name}).
@@ -330,7 +332,7 @@ def get_calib_hists(
         Dictionary with an efficiency histogram for each reference particle.
         The reference particle prefixes are the dictionary keys.
     """
-    hists = {}
+    hists: Dict[str, Dict[str, bh.Histogram]] = {}
     for ref_par in ref_pars:
         particle = ref_pars[ref_par][0]
 
@@ -348,10 +350,15 @@ def get_calib_hists(
             ),
         )
 
-        log.debug(f"Loading efficiency histogram from '{calib_name}'")
+        log.debug(f"Loading efficiency histograms from '{calib_name}'")
 
+        hists[ref_par] = {}
         with open(calib_name, "rb") as f:
-            hists[ref_par] = pickle.load(f)
+            hists[ref_par]["eff"] = pickle.load(f)
+            hists[ref_par]["passing"] = pickle.load(f)
+            hists[ref_par]["total"] = pickle.load(f)
+            hists[ref_par]["passing_sumw2"] = pickle.load(f)
+            hists[ref_par]["total_sumw2"] = pickle.load(f)
     return hists
 
 
@@ -360,6 +367,8 @@ def save_dataframe_as_root(
 ):
     """Save a DataFrame as a TTree in a ROOT file.
 
+    NaN entries are changed to -999 because ROOT TTrees don't support NaNs.
+
     Args:
         df: DataFrame to be saved.
         name: Name of the new TTree.
@@ -367,12 +376,13 @@ def save_dataframe_as_root(
         columns: Optional. Names of the columns which are to be saved. If
             'None', all the columns will be saved.
     """
+    df_wo_nan = df.fillna(-999)
     if columns is None:
-        columns = list(df.keys())
-    branches_w_types = {branch: df[branch].dtype for branch in columns}
+        columns = list(df_wo_nan.keys())
+    branches_w_types = {branch: df_wo_nan[branch].dtype for branch in columns}
     with uproot3.recreate(filename) as f:
         log.debug(f"Creating a TTree with the following branches: {branches_w_types}")
         f[name] = uproot3.newtree(branches_w_types)
-        branch_dict = {branch: df[branch] for branch in branches_w_types}
+        branch_dict = {branch: df_wo_nan[branch] for branch in branches_w_types}
         f[name].extend(branch_dict)
     log.info(f"Efficiency tree saved to {filename}")
