@@ -32,9 +32,8 @@ def test_make_hist():
 def test_create_eff_histograms():
     df = pd.read_csv(Path(THIS_DIR, "test_data/cal_test_data.csv"), index_col=0)
     hists = utils.create_eff_histograms(df, "Pi", ["DLLK>4"], ["P"])
-    assert hists["eff_DLLK>4"].sum() / hists["eff_DLLK>4"].size == pytest.approx(
-        0.18751578358705173 / 20
-    )
+    assert hists["eff_DLLK>4"].sum() == pytest.approx(0.18751578358705173)
+    assert hists["eff_DLLK>4"].size == 20
 
 
 def test_get_per_event_effs():
@@ -42,13 +41,19 @@ def test_get_per_event_effs():
     prefixes = ["Bach"]
     bin_vars = {"P": "P", "ETA": "ETA", "nTracks": "nTracks"}
     hists = {}
+    hists["Bach"] = {}
     with open(
         Path(THIS_DIR, "test_data/effhists_Turbo18_up_K_DLLK>4_P-ETA-nTracks.pkl"), "rb"
     ) as f:
-        hists["Bach"] = pickle.load(f)
+        hists["Bach"]["eff"] = pickle.load(f)
+        hists["Bach"]["passing"] = pickle.load(f)
+        hists["Bach"]["total"] = pickle.load(f)
+        hists["Bach"]["passing_sumw2"] = pickle.load(f)
+        hists["Bach"]["total_sumw2"] = pickle.load(f)
     df_ref = utils.add_bin_indices(df_ref, prefixes, bin_vars, hists)
-    df_ref = utils.add_efficiencies(df_ref, prefixes, hists)
-    assert df_ref.PID_eff.mean() == pytest.approx(0.8951140908087826)
+    with pytest.warns(RuntimeWarning):
+        df_ref = utils.add_efficiencies(df_ref, prefixes, hists)
+    assert df_ref.PIDCalibEff.mean() == pytest.approx(0.8745793984247746)
 
 
 def test_add_bin_indices():
@@ -56,11 +61,16 @@ def test_add_bin_indices():
     prefixes = ["Bach"]
     bin_vars = {"P": "P", "ETA": "ETA", "nTracks": "nTracks"}
     hists = {}
+    hists["Bach"] = {}
     with open(
         Path(THIS_DIR, "test_data/effhists_Turbo18_up_K_DLLK>4_P-ETA-nTracks.pkl"), "rb"
     ) as f:
-        hists["Bach"] = pickle.load(f)
+        hists["Bach"]["eff"] = pickle.load(f)
+        hists["Bach"]["passing"] = pickle.load(f)
+        hists["Bach"]["total"] = pickle.load(f)
+        hists["Bach"]["passing_sumw2"] = pickle.load(f)
+        hists["Bach"]["total_sumw2"] = pickle.load(f)
     df_ref = utils.add_bin_indices(df_ref, prefixes, bin_vars, hists)
-    assert df_ref["Bach_P_PID_index"].sum() == 623
-    assert df_ref["Bach_ETA_PID_index"].sum() == 120
-    assert df_ref["Bach_PID_index"].sum() == 10438
+    assert df_ref["Bach_P_PIDCalibBin"].sum() == 623
+    assert df_ref["Bach_ETA_PIDCalibBin"].sum() == 120
+    assert df_ref["Bach_PIDCalibBin"].sum() == 10438
